/**
 * @file
 * Protected Content dialog .
 */
(function($, Drupal, once, drupalSettings, window) {
  Drupal.behaviors.ProcDecryptDialogBehavior = {
    attach: function(context, settings) {
      once('procDecryptDialogProcessed', '.proc-attach-dialog', context).forEach(function(element) {

        let field_info = drupalSettings.proc[element.getAttribute('data-proc-field-name')];
        let element_href = element.getAttribute("href").replace(drupalSettings.path.baseUrl, '');
        let path_prefix = window.location.origin + drupalSettings.path.baseUrl + element_href;
        let path_suffix = "?proc_standalone_mode=FALSE";
        path_suffix += "&proc_field_name='" + element.getAttribute('data-proc-field-name') + "'";
        // @todo Finish retrieving field widget settings.
        if (field_info['settings']) {
          path_suffix =  (field_info['settings']['proc_allow_password_caching'])
            ? "&cache-password=" + field_info['settings']['proc_allow_password_caching']
            : '';
          path_suffix += (field_info['settings']['proc_field_input_mode'])
            ? "&field-input-mode=" + field_info['settings']['proc_field_input_mode']
            : '';
          path_suffix += (field_info['settings']['proc_field_decryption_mode'])
            ? "&field-decryption-mode=" + field_info['settings']['proc_field_decryption_mode']
            : '';
          path_suffix += (field_info['settings']['proc_trigger_format'])
            ?"&trigger-fields=" + field_info['settings']['proc_trigger_format']
            : '';
        }
        let proc_path = path_prefix + '/' + path_suffix;

        let ajaxSettings = {
          url: proc_path,
          dialogType: "dialog",
          dialog: { width: 400, classes: { "ui-dialog": "class-" +  element.getAttribute('data-proc-field-name')} },
        };
        let decryptDialog = Drupal.ajax(ajaxSettings);
        $(element).on('click', function(event) {
          event.preventDefault();
          let ajaxExecute = decryptDialog.execute();
          ajaxExecute.done(() => {
            console.info('Opening decrypt modal form');
          })
          .fail(() => {
            let msg = Drupal.t('Access denied for this content.');
            // Prepare feedback message for the user.
            var DecryptErrorAjaxMsg = Drupal.ajax({
              url: '/proc/modal-message?msg=' + msg,
              dialogType: 'modal',
              dialog: { width: 400 },
            });
            // Display the error on a modal.
            DecryptErrorAjaxMsg.execute();
          })

        });
      });
    },
  };
})(jQuery, Drupal, once, drupalSettings, window);
