/**
 * @file
 * Helper for entity reference proc field.
 *
 * @todo: we must apply this proc-field library as a gate to all dialog calls, or change its name to something less
 * generic.
 */
(function($, Drupal, drupalSettings, once) {
  Drupal.behaviors.ProcBehavior = {
    'attach': (context, settings) => {
      once('proc-decrypt', 'html', context).forEach(function(element) {
        const procFieldElements = document.querySelectorAll('[proc="true"]');
        const procFields = [];

        procFieldElements.forEach((fieldElement, fieldElementIndex) => {
          procFields.push(
            fieldElement.attributes.name.value.substring(
              0,
              fieldElement.attributes.name.value.indexOf('['),
            ),
          );
        });

        if (drupalSettings.proc && drupalSettings.proc.submit_element_id) {
          const isMultipleSubmits = (drupalSettings.proc.submit_element_id.search(',') > -1);

          if (isMultipleSubmits) {
            const submitIds = drupalSettings.proc.submit_element_id.split(',');
            submitIds.forEach((submitIdValue) =>{
              Drupal.behaviors.ProcBehavior.processSubmitButton(submitIdValue.trim(), procFields);
            });
          }
          else {
            const submitId = drupalSettings.proc.submit_element_id.trim();
            Drupal.behaviors.ProcBehavior.processSubmitButton(submitId, procFields);
          }
        }
      });
    },
    'processSubmitButton': (submit_element_id, procFields) => {
      let submitElement = document.getElementById(submit_element_id);

      procFields.map((fieldName, fieldIndex) => {
        var field = document.querySelector(`[name^="${fieldName}"]`);
        field.oninput = () => {
          if (submitElement.disabled === false && field.value != '') {
            // Disable submit when something is typed in for encryption:
            submitElement.disabled = true;
          }
          if (submitElement.disabled === true && field.value === '') {
            submitElement.disabled = false;
          }
        };

        var encryptCheckbox = document.querySelector(`[id="encrypt-checkbox-${fieldName}"]`);

        if (encryptCheckbox) {
          encryptCheckbox.oninput = () => {
            if (
              encryptCheckbox.value === '1' &&
              submitElement.disabled === true
            ) {
              // If for all other fields there is no plain text:
              let index = 0;
              procFields.map((fieldName, fieldIndex) => {
                if (
                  !document
                    .querySelector(`[name^="${fieldName}"]`)
                    .value.startsWith('******* (')
                ) {
                  index++;
                }
              });
              if (index === 1) {
                submitElement.disabled = false;
              }
            }
            if (
              encryptCheckbox.value === '0' &&
              submitElement.disabled === false
            ) {
              submitElement.disabled = true;
            }
          };
        }
      });
    }
  };
})(jQuery, Drupal, drupalSettings, once);
